function m0432
%  m0432.m     (Matlab/Simulink R2007b)
%
%  Bild 4.32 a und b
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme: s0432.mdl
%
%  (c)15.11.08  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%    Zeitkonstante T1   im Bereich 0.0005 < T1  <  5.
%
%      T1=0.0005: Bild 4.32a
%      T1=0.1   : Bild 4.32b
%
%    Schalter schalt=1: P- und D-Anteil verzgert
%             schalt=0: Nur D-Anteil verzgert
%
%    P-Beiwert     Kpr  im Bereich    0   < Kpr <  1.5 
%    Vorhaltzeit   Tv   im Bereich    0   < Tv  <  1.5 
%
%    Sprunghhe   edach im Bereich    0   < edach <  1. 
%
%
% ########################################################
clear


    T1=.1;       % Voreinstellung: T1 =.1

    schalt=1;    % Voreinstellung: schalt=1

    Kpr=10;      % Voreinstellung: Kpr=10
    Tv=.5;       % Voreinstellung: Tv =.5

    edach=1.;     % Voreinstellung: edach=1     


% ########################################################

menu='none';  % none oder fig
close all
fonts=8;

tsprung=.1;   % Zeitpunkt der Sprunganregung
te=.9; 

% Base-Workspace fr Simulink
assignin('base','tsprung',tsprung)
assignin('base','edach',edach)
assignin('base','Kpr',Kpr)
assignin('base','schalt',schalt)
assignin('base','T1',T1)
assignin('base','Tv',Tv)

opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',.001);
[t,x,y]=sim('s0432',[0 te],opts);

figure(1)
set(gcf,'Units','normal','Position',[.53 .66 .45 .23], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Zu Bild 4.32');
buch(gcf)

tachs1=[-0.1 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k'),grid on, hold on
set(gca,'FontSize',fonts,...
    'Position',[.15 .2 .75 .65]);
axis([-0.1 te -.2 1.2]); 
fachs1=[0 0]; fachs2=[-0.2 1.2];
plot(fachs1,fachs2,'k')
% Funktionsverlauf:
plot(t,y(:,1),'LineW',2)
% t<0
tm=[-.1 0]; fm=[0 0];
plot(tm,fm,'b','LineW',2)

title('Regeldifferenz')
xlabel('t \rightarrow')
ylabel('e \rightarrow')


figure(2)
set(gcf,'Units','normal','Position',[.53 .34 .45 .23], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 4.32 a bzw. b');
buch(gcf)

tachs1=[-0.1 te]; tachs2=[0 0];     % Koordinatenachsen
plot(tachs1,tachs2,'k'),grid on, hold on
set(gca,'FontSize',fonts,...
    'Position',[.15 .2 .75 .65]);
axis([-0.1 te -5 65]); 
fachs1=[0 0]; fachs2=[-5 65];
plot(fachs1,fachs2,'k')
% Funktionsverlufe:
plot(t,y(:,2),'b','LineW',2), grid on, hold on
plot(t,y(:,3),'g--',t,y(:,4),'r--')
% t<0
plot(tm,fm,'b','LineW',2)

title('Stellgre blau  (grn: P-Anteil, rot: D-Anteil)')
xlabel('t \rightarrow')
ylabel('y \rightarrow')




















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')

