function m0706
%  m0706.m     (Matlab/Simulink R2007b)
%
%  Bild 7.6 a und b
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme:  s0706_1.mdl, s0706_2.mdl, 
%                   s0706_3.mdl, s0706_4.mdl
%
%  (c)15.11.08  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%    Abtastperiode   T     im Bereich 10    <  T    < 30.
%
%  Sprungantwort (Bild 7.6a):
%    Sprunghhe     udach  im Bereich .5    < udach < 1.
%
%  Schwingungsantwort (Bild 7.6b):
%    Amplitude      udach  im Bereich .5    < udach < 1.
%    Kreisfrequenz  om0    im Bereich .0005 < om0 < 0.01.
%
% ########################################################
clear

     T=20;           %  Voreinstellung T=20

     udach=1;        %  Voreinstellung udach=1

     om0=.0005;      %  Voreinstellung 0m0=0.0005

% ########################################################

menu='none';  % none oder fig
close all
fonts=8;

% Fllstandstrecke:

% Analoges Modell:
A=30*1e-4;   % A=30cm^2    - Tankquerschnitt in m^2
rho=1e3;     % rho=1g/cm^3 - Flss.dichte in kg/m^3
cP=2e-3;     % cP=2(g/s)/V - Motorkonstante in (kg/s)/V
g=9.81;      % Erdbeschleunigung in m/s^2

c1=sqrt(2*g)/A;  c2=cP/(rho*A);

% Arbeitspunkt:
hs=10;       % in cm
Aab0=6;      % in mm^2
hs=1e-2*hs; % Umrechnung in m
Aab0=1e-6*Aab0; % Umrechnung in m^2
up0=(c1/c2)*Aab0*sqrt(hs);

k=1/(2*sqrt(hs));
a0=c1*Aab0*k;
b01=c2;
KPS=b01/a0; T1=1/a0;    
zae=[KPS]; nen=[T1 1]; 

% Digitales Modell:
a=exp(-T/T1); % Formeln gem Buch S.245 unten  
b0=1-a;
a1=-a;
zaed=KPS*b0; nend=[1 a1]; 


% In Workspace ablegen (fr Simulink)
assignin('base','T',T)
assignin('base','udach',udach)
assignin('base','om0',om0)
assignin('base','zae',zae)
assignin('base','nen',nen)
assignin('base','zaed',zaed)
assignin('base','nend',nend)




figure(1)
set(gcf,'Units','normal','Position',[.53 .6 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 7.6a'); 
buch(gcf)  

te=300; 

opts=simset('Solver','ode45',...
    'InitialState',[0],...
    'MaxStep',1.);

[t1,x1,y1]=sim('s0706_1',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0],...
    'FixedStep',T);

[t2,x2,y2]=sim('s0706_2',[0 te],opts);

subplot(2,1,1)
plot(t1,y1(:,1),'g'),grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -.5 1.5]); 
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y')

subplot(2,1,2)
y1(:,2)=1e2*y1(:,2);  % Umrechnung Dh in cm
y2(:,2)=1e2*y2(:,2);  % Umrechnung Dh in cm
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -1 6]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')

figure(2)
set(gcf,'Units','normal','Position',[.53 .1 .45 .35], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 7.6b'); 
buch(gcf)  

te=300; 

opts=simset('Solver','ode45',...
    'InitialState',[0],...
    'MaxStep',.1);

[t1,x1,y1]=sim('s0706_3',[0 te],opts);

opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[0],...
    'FixedStep',T);

[t2,x2,y2]=sim('s0706_4',[0 te],opts);

subplot(2,1,1)
plot(t1,y1(:,1),'g'),grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -.5 1.5]); 
plot(t2,y2(:,1),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
title('Grn: Analoges Modell, Blau: Digitales Modell')
ylabel('y')

subplot(2,1,2)
y1(:,2)=1e2*y1(:,2);  % Umrechnung Dh in cm
y2(:,2)=1e2*y2(:,2);  % Umrechnung Dh in cm
plot(t1,y1(:,2),'g'), grid on, hold on
set(gca,'FontSize',fonts);
axis([0 te -1 6]); 
plot(t2,y2(:,2),'bx','LineW', 2)
tachs1=[0 te]; tachs2=[0 0];
plot(tachs1,tachs2,'k')
ylabel('x')




















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')


