function m0905
%  m0905.m     (Matlab/Simulink R2007b)
%
%  Bild 9.5
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme:  s0905.mdl
%
%  (c)15.11.08  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%   Sollsprunghhe Spiegelwinkel wdach (in Grad) 
%                      im Bereich  1.  <  wdach <  6.
%
%  Regler:
%   P-Beiwert    Kpr   im Bereich  3.    < Kpr  <  30.
%   Parameter    TD    im Bereich  0.05  < TD   <  0.3
%   Parameter    T1=0.01*TD  (fest)  
%
% ########################################################
clear

     wdach = 5.;      % Voreinstellung  wdachgrad=5.

     Kpr   =10.;      % Voreinstellung  Kpr=10.

     TD    =.1;       % Voreinstellung  TD = 0.1

% ########################################################

menu='none';  % none oder fig
close all
fonts=8;

% Scannermodell:
J=.001;        % Nm/(rad/s^2)=Nms^2, Trgheitsmom.
cR=0.01;       % Nm/(rad/s)=Nms, Reibung
KIS=1/cR; T1=J/cR;    
szae=[KIS] ;
snen=[T1 1 0];

% Lead-Regler: Gr=Kpr*(TD*s+1)/(T1*s+1), TD>T1
T1=.01*TD;
rzae=Kpr*[TD 1];
rnen=[T1  1];

% Fhrungssprungantwort:
wdachrad=wdach*pi/180;

% Daten fr Simulink in den workspace
assignin('base','szae',szae);
assignin('base','snen',snen);
assignin('base','rzae',rzae);
assignin('base','rnen',rnen);
assignin('base','wdachrad',wdachrad);


figure(1)
set(gcf,'Units','normal','Position',[.53 .55 .45 .3], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 9.5');
buch(gcf)

t0=-0.001; te=.01; 

opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',te/100);

[t,x,y]=sim('s0905',[0 te],opts);


t=t*1e3;    % s --> ms
t0ms=t0*1e3; tems=te*1e3;
y(:,1)=y(:,1)*180/pi;
y(:,2)=y(:,2)*180/pi;
tachs1=[t0ms tems]; tachs2=[0 0]; 
fachs1=[0 0]; fachs2=[-.5 8]; 
plot(tachs1,tachs2,'k',fachs1,fachs2,'k')
grid on, hold on
set(gca,'FontSize',fonts,...
    'xtick',[-1:10],...
    'ytick',[0:2:10]);
axis([t0ms tems -.5 8.] ); 
title(' Laserscanner-Regelung')
xlabel('t/ms'); ylabel('w, \phi (Grad)')
plot(t,y(:,1),'r',t,y(:,2),'b')

figure(2)
set(gcf,'Units','normal','Position',[.53 .15 .45 .3], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Zugehriger Stellgrenverlauf');
buch(gcf)

fachs1=[0 0]; fachs2=[-5 10]; 
plot(tachs1,tachs2,'k',fachs1,fachs2,'k')
grid on, hold on
set(gca,'FontSize',fonts,...
    'xtick',[-1:10],'ytick',[-5:5:10]);
axis([ t0ms tems -5 10]); 
xlabel('t/ms'); ylabel('u_M (V)')
y(:,3)=y(:,3)*.1;     % Nm -> V
plot(t,y(:,3))


function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')


