function m0906
%  m0906.m     (Matlab/Simulink R2007b)
%
%  Bild 9.6 b, c und d
%  Mann/Schiffelgen/Froriep,
%  Einfhrung in die Regelungstechnik, 
%  10.Aufl., Hanser-Verlag, Mnchen, 2005
%  ISBN 3-446-40303-5
%
%  Unterprogramme: s0906_1.mdl, s0906_2.mdl, s0906_3.mdl 
%
%  (c)15.11.08  R.Froriep
%
% ########################################################
%
%  Variations-Empfehlungen:
%
%   wdach   Sollsprunghhe Spiegelwinkel (in Grad)
%           im Bereich  1.  < wdach  <  6.
%
%  Regler:
%   T       Abtastintervall (in ms)
%           im Bereich  0.05   < T    <   1.
%
%   Kpr     P-Beiwert im Bereich  3.    <  Kpr  <  30.
%   TD      Parameter im Bereich  0.05  <  TD   <    0.3
%
% ########################################################
clear

wdach = 5.;      % Voreinstellung  wdach=5.

T = .1;          % Voreinstellung  T=0.1

Kpr =10.;        % Voreinstellung  Kpr=10.
TD  =.1;         % Voreinstellung  TD = 0.1

% ########################################################

menu='none';  % none oder fig
close all
fonts=8;

% Lead-Regler: Gr=Kpr*(TD*s+1)/(T1*s+1), TD>T1
T1=.01*TD;
tt0=1e-3;         % Umrechnungsfaktor
TD=TD/tt0;        % s --> ms
T1=T1/tt0;        % s --> ms
rzae=Kpr*[TD 1];
rnen=[T1  1];

% Digitale Reglerrealisierung 
% (Trapezregel, Buch S.235):
b0=Kpr*(T+2*TD)/(T+2*T1);
b1=Kpr*(T-2*TD)/(T+2*T1);
a0=1;
a1=(T-2*T1)/(T+2*T1);
rzaed=[b0 b1];
rnend=[a0 a1];

% Gs(s):
J=.001;        % Nms^2, Trgheitsmoment
cR=0.01;       % Nms, Reibung
KIS=1/cR; T1=J/cR;    
KIS=KIS*tt0;    % s --> ms
T1=T1/tt0;      % s --> ms
szae=[KIS]; 
snen=[T1 1 0];

% Diskretisierung Strecke (Buch S.251):
alf=exp(-T/T1);
b0S=0;         
b1S=-KIS*((1-alf)*T1 -     T);
b2S= KIS*((1-alf)*T1 - alf*T);
a1S=-(1+alf);
a2S=alf;
szaed=[b0S b1S b2S];
snend=[1  a1S  a2S];


figure(1)   % Fhrungssprungantwort analog u. digital
set(gcf,'Units','normal','Position',[.47 .65 .51 .27], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 9.6b');
buch(gcf)

% Analoge Regelung:
wdachrad=wdach*pi/180;
te=10;  

% In Base-Workspace ablegen (fr Simulink)
assignin('base','wdachrad',wdachrad)
assignin('base','szae',szae)
assignin('base','snen',snen)
assignin('base','rzae',rzae)
assignin('base','rnen',rnen)
assignin('base','T',T)
assignin('base','rzaed',rzaed)
assignin('base','rnend',rnend)
assignin('base','szaed',szaed)
assignin('base','snend',snend)

opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',te/100);
[t,x,y]=sim('s0906_1',[0 te],opts);

y(:,1)=y(:,1)*180/pi;
y(:,2)=y(:,2)*180/pi;
t0=-1.;  
tachs1=[t0 te]; tachs2=[0 0];
yachs1=[0 0]; yachs2=[-1 8];
plot(tachs1,tachs2,'k',yachs1,yachs2,'k')
grid on, hold on
set(gca,'Position',[.15 .2 .75 .7],...
    'FontSize',fonts,...
    'xtick',[-1:10],...
    'ytick',[0:2:10]);
xlabel('t (ms)'); ylabel('w, \phi (Grad)')
title(['Regelung analog: hellblau;  digital: dunkelblau (T=',...
        num2str(T),'ms)'])
axis([t0 te -.5 8.]); 
plot(t,y(:,1),'r-',t,y(:,2),'c-')

% Digitale Regelung:
% 1.) w und x auch zwischen kT:
opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',T/10);
[t,x,y]=sim('s0906_2',[0 te],opts);
y(:,2)=y(:,2)*180/pi;
plot(t,y(:,2),'b')

% 2.) w und x nur fr kT:
opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[],...
    'FixedStep',T);
[t,x,yk]=sim('s0906_3',[0 te],opts);

yk(:,2)=yk(:,2)*180/pi;
plot(t,yk(:,2),'bx','markersize',5,'LineW',1)
% Funktionswerte fr k<0 Null setzen:
km=floor(abs(t0)/T); % Anzahl Abtastpunkte vor t=0
tkm=[-km:-1]*T; fkm=zeros(size(tkm));
plot(tkm,fkm,'bx','markersize',5,'LineW',1)


open_system('s0906_2')    % Simulink-Fenster ffnen


figure(2)
set(gcf,'Units','normal','Position',[.47 .05 .51 .27], ...
    'NumberTitle','off','MenuBar',menu,...
    'Name',' Bild 9.6d');
buch(gcf)

% Analoge Regelung:
opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',te/100);
[t,x,y]=sim('s0906_1',[0 te],opts);

tachs1=[t0 te]; tachs2=[0 0];
yachs1=[0 0]; yachs2=[-5 10];
plot(tachs1,tachs2,'k',yachs1,yachs2,'k')
grid on, hold on
set(gca,'Position',[.15 .2 .75 .7],...
    'FontSize',fonts,...
    'xtick',[-1:10],'ytick',[-5:5:10]);
xlabel('t (ms)'); ylabel('u_m (V)')
title('Regelung analog: hellblau;  digital: dunkelblau')
axis([t0 te -5 10]); 
y(:,3)=y(:,3)*.1;     % Nm -> V
plot(t,y(:,3),'c-')

% Digitale Regelung:
% 1.) y auch zwischen kT:
opts=simset('Solver','ode45',...
    'InitialState',[],...
    'MaxStep',T/10);
[t,x,y]=sim('s0906_2',[0 te],opts);

y(:,3)=y(:,3)*.1;     % Nm -> V
plot(t,y(:,3),'b')

% 2.) y nur fr kT:
opts=simset('Solver','FixedStepDiscrete',...
    'InitialState',[],...
    'FixedStep',T);
[t,x,yk]=sim('s0906_3',[0 te],opts);

yk(:,3)=yk(:,3)*.1;     % Nm -> V
plot(t,yk(:,3),'bx','markersize',5,'linewidth',1)
% Funktionswerte fr k<0 Null setzen:
plot(tkm,fkm,'bx','markersize',5,'LineW',1)

















function []=buch(fighandle)
cr0=uimenu('parent', fighandle);
set(cr0,'Label','?') 
cr1=uimenu('parent', cr0);
set(cr1,'Label','Mann/Schiffelgen/Froriep') 
cr2=uimenu('parent', cr0);
set(cr2,'Label','Einfhrung in die Regelungstechnik') 
cr3=uimenu('parent', cr0);
set(cr3,'Label','Hanser-Verlag')

